@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2023 Laurent Montel <montel@kde.org>
   SPDX-FileCopyrightText: 2013 Jonathan Marten <jjm@keelhaul.me.uk>
 
   SPDX-License-Identifier: GPL-2.0-only
@@ -32,11 +32,11 @@ public:
     void save(Akonadi::Collection &collection) override;
 
 private:
-    void saveAndExpire(Akonadi::Collection &collection, bool saveSettings, bool _expirenow);
-    void init();
-    void slotChanged();
-    void slotSaveAndExpire();
-    void slotConfigChanged(bool changed);
+    MAILCOMMON_NO_EXPORT void saveAndExpire(Akonadi::Collection &collection, bool saveSettings, bool _expirenow);
+    MAILCOMMON_NO_EXPORT void init();
+    MAILCOMMON_NO_EXPORT void slotChanged();
+    MAILCOMMON_NO_EXPORT void slotSaveAndExpire();
+    MAILCOMMON_NO_EXPORT void slotConfigChanged(bool changed);
     CollectionExpiryWidget *mCollectionExpiryWidget = nullptr;
     Akonadi::Collection mCollection;
     bool mChanged = false;
@@ -44,4 +44,3 @@ private:
 
 AKONADI_COLLECTION_PROPERTIES_PAGE_FACTORY(CollectionExpiryPageFactory, CollectionExpiryPage)
 }
-
