@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -47,8 +47,8 @@ protected:
     void init(const Akonadi::Collection &);
 
 private:
-    void slotFolderContentsSelectionChanged(int);
-    void slotNameChanged(const QString &name);
+    MAILCOMMON_NO_EXPORT void slotFolderContentsSelectionChanged(int);
+    MAILCOMMON_NO_EXPORT void slotNameChanged(const QString &name);
 
 private:
     QString mColorName;
