@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -27,7 +27,7 @@ public:
     void load(const Akonadi::Collection &col);
 
 private:
-    void slotIdentityCheckboxChanged();
+    MAILCOMMON_NO_EXPORT void slotIdentityCheckboxChanged();
     QCheckBox *mNotifyOnNewMailCheckBox = nullptr;
     QCheckBox *mKeepRepliesInSameFolderCheckBox = nullptr;
     QCheckBox *mHideInSelectionDialogCheckBox = nullptr;
