@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -9,7 +9,7 @@
 #include <KLocalizedString>
 #include <QFormLayout>
 
-#include <Akonadi/KMime/MessageFolderAttribute>
+#include <Akonadi/MessageFolderAttribute>
 #include <MessageList/AggregationComboBox>
 #include <MessageList/AggregationConfigButton>
 #include <MessageList/ThemeComboBox>
@@ -79,12 +79,9 @@ CollectionViewWidget::CollectionViewWidget(QWidget *parent)
     topLayout->addRow(QString(), mPreferTextToHtml);
     mUseGlobalSettings = new QRadioButton(i18n("Use Global Settings"), this);
     topLayout->addRow(QString(), mUseGlobalSettings);
-
 }
 
-CollectionViewWidget::~CollectionViewWidget()
-{
-}
+CollectionViewWidget::~CollectionViewWidget() = default;
 
 void CollectionViewWidget::load(const Akonadi::Collection &col)
 {
