@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -18,9 +18,7 @@ FilterActionMissingAccountDialogTest::FilterActionMissingAccountDialogTest(QObje
     QStandardPaths::setTestModeEnabled(true);
 }
 
-FilterActionMissingAccountDialogTest::~FilterActionMissingAccountDialogTest()
-{
-}
+FilterActionMissingAccountDialogTest::~FilterActionMissingAccountDialogTest() = default;
 
 void FilterActionMissingAccountDialogTest::shouldHaveDefaultValue()
 {
