@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -20,9 +20,7 @@ FilterActionMissingTransportDialogTest::FilterActionMissingTransportDialogTest(Q
     QStandardPaths::setTestModeEnabled(true);
 }
 
-FilterActionMissingTransportDialogTest::~FilterActionMissingTransportDialogTest()
-{
-}
+FilterActionMissingTransportDialogTest::~FilterActionMissingTransportDialogTest() = default;
 
 void FilterActionMissingTransportDialogTest::shouldHaveDefaultValue()
 {
