@@ -1,33 +1,20 @@
 /*
-  Copyright (c) 2015-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "invalidfilterlistwidgettest.h"
-#include <QTest>
-#include "../filter/invalidfilters/invalidfilterlistview.h"
 #include "../filter/invalidfilters/invalidfilterinfo.h"
+#include "../filter/invalidfilters/invalidfilterlistview.h"
+#include <QTest>
 
 InvalidFilterListWidgetTest::InvalidFilterListWidgetTest(QObject *parent)
     : QObject(parent)
 {
 }
 
-InvalidFilterListWidgetTest::~InvalidFilterListWidgetTest()
-{
-}
+InvalidFilterListWidgetTest::~InvalidFilterListWidgetTest() = default;
 
 void InvalidFilterListWidgetTest::shouldHaveDefaultValue()
 {
