@@ -1,6 +1,6 @@
 /*
 
-  SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -46,8 +46,7 @@ private:
 private:
     void writeConfig();
     void readConfig();
-    MailCommon::FolderRequester *mFolderRequester = nullptr;
+    MailCommon::FolderRequester *const mFolderRequester;
     QListWidget *mListwidget = nullptr;
     QPushButton *mOkButton = nullptr;
 };
-
