@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -26,7 +26,6 @@ public:
 private:
     void readConfig();
     void writeConfig();
-    SelectThunderbirdFilterFilesWidget *mSelectFilterFilesWidget = nullptr;
+    SelectThunderbirdFilterFilesWidget *const mSelectFilterFilesWidget;
 };
 }
-
