@@ -1,27 +1,15 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #include "filteractionrewriteheader.h"
 
+#include <KComboBox>
 #include <KLineEdit>
 #include <KLocalizedString>
-#include <KComboBox>
 
 #include <QHBoxLayout>
 #include <QLabel>
@@ -36,20 +24,15 @@ FilterAction *FilterActionRewriteHeader::newAction()
 FilterActionRewriteHeader::FilterActionRewriteHeader(QObject *parent)
     : FilterActionWithStringList(QStringLiteral("rewrite header"), i18n("Rewrite Header"), parent)
 {
-    mParameterList << QString()
-                   << QStringLiteral("Subject")
-                   << QStringLiteral("Reply-To")
-                   << QStringLiteral("Delivered-To")
-                   << QStringLiteral("X-KDE-PR-Message")
-                   << QStringLiteral("X-KDE-PR-Package")
-                   << QStringLiteral("X-KDE-PR-Keywords");
+    mParameterList << QString() << QStringLiteral("Subject") << QStringLiteral("Reply-To") << QStringLiteral("Delivered-To")
+                   << QStringLiteral("X-KDE-PR-Message") << QStringLiteral("X-KDE-PR-Package") << QStringLiteral("X-KDE-PR-Keywords");
 
     mParameter = mParameterList.at(0);
 }
 
 bool FilterActionRewriteHeader::isEmpty() const
 {
-    return mParameter.isEmpty() || mRegExp.isEmpty();
+    return mParameter.isEmpty() || mRegex.pattern().isEmpty();
 }
 
 QString FilterActionRewriteHeader::informationAboutNotValidAction() const
@@ -58,7 +41,7 @@ QString FilterActionRewriteHeader::informationAboutNotValidAction() const
     if (mParameter.isEmpty()) {
         info = i18n("Header not defined");
     }
-    if (mRegExp.isEmpty()) {
+    if (mRegex.pattern().isEmpty()) {
         if (!info.isEmpty()) {
             info += QLatin1Char('\n');
         }
@@ -73,17 +56,17 @@ FilterAction::ReturnCode FilterActionRewriteHeader::process(ItemContext &context
         return ErrorButGoOn;
     }
 
-    const KMime::Message::Ptr msg = context.item().payload<KMime::Message::Ptr>();
+    const auto msg = context.item().payload<KMime::Message::Ptr>();
 
     const QByteArray param(mParameter.toLatin1());
     KMime::Headers::Base *header = msg->headerByType(param.constData());
     if (!header) {
-        return GoOn; //TODO: Maybe create a new header by type?
+        return GoOn; // TODO: Maybe create a new header by type?
     }
 
     QString value = header->asUnicodeString();
     const QString oldValue = value;
-    const QString newValue = value.replace(mRegExp, mReplacementString);
+    const QString newValue = value.replace(mRegex, mReplacementString);
     if (newValue != oldValue) {
         msg->removeHeader(param.constData());
 
@@ -107,10 +90,10 @@ SearchRule::RequiredPart FilterActionRewriteHeader::requiredPart() const
 
 QWidget *FilterActionRewriteHeader::createParamWidget(QWidget *parent) const
 {
-    QWidget *widget = new QWidget(parent);
-    QHBoxLayout *layout = new QHBoxLayout(widget);
+    auto widget = new QWidget(parent);
+    auto layout = new QHBoxLayout(widget);
     layout->setSpacing(4);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setContentsMargins({});
 
     auto comboBox = new KComboBox(widget);
     comboBox->setMinimumWidth(50);
@@ -124,12 +107,12 @@ QWidget *FilterActionRewriteHeader::createParamWidget(QWidget *parent) const
     comp->insertItems(mParameterList);
     comp->setCompletionMode(KCompletion::CompletionPopupAuto);
 
-    QLabel *label = new QLabel(i18n("Replace:"), widget);
+    auto label = new QLabel(i18n("Replace:"), widget);
     label->setObjectName(QStringLiteral("label_replace"));
     label->setFixedWidth(label->sizeHint().width());
     layout->addWidget(label, 0);
 
-    KLineEdit *regExpLineEdit = new KLineEdit(widget);
+    auto regExpLineEdit = new KLineEdit(widget);
     regExpLineEdit->setClearButtonEnabled(true);
     regExpLineEdit->setTrapReturnKey(true);
     regExpLineEdit->setObjectName(QStringLiteral("search"));
@@ -140,16 +123,15 @@ QWidget *FilterActionRewriteHeader::createParamWidget(QWidget *parent) const
     label->setObjectName(QStringLiteral("label_with"));
     layout->addWidget(label, 0);
 
-    KLineEdit *lineEdit = new KLineEdit(widget);
+    auto lineEdit = new KLineEdit(widget);
     lineEdit->setObjectName(QStringLiteral("replace"));
     lineEdit->setClearButtonEnabled(true);
     lineEdit->setTrapReturnKey(true);
     layout->addWidget(lineEdit, 1);
 
     setParamWidgetValue(widget);
-    connect(comboBox, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &FilterActionRewriteHeader::filterActionModified);
-    connect(comboBox->lineEdit(), &QLineEdit::textChanged,
-            this, &FilterAction::filterActionModified);
+    connect(comboBox, &KComboBox::currentIndexChanged, this, &FilterActionRewriteHeader::filterActionModified);
+    connect(comboBox->lineEdit(), &QLineEdit::textChanged, this, &FilterAction::filterActionModified);
     connect(regExpLineEdit, &KLineEdit::textChanged, this, &FilterActionRewriteHeader::filterActionModified);
     connect(lineEdit, &KLineEdit::textChanged, this, &FilterActionRewriteHeader::filterActionModified);
 
@@ -171,11 +153,11 @@ void FilterActionRewriteHeader::setParamWidgetValue(QWidget *paramWidget) const
         comboBox->setCurrentIndex(index);
     }
 
-    KLineEdit *regExpLineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("search"));
+    auto *regExpLineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("search"));
     Q_ASSERT(regExpLineEdit);
-    regExpLineEdit->setText(mRegExp.pattern());
+    regExpLineEdit->setText(mRegex.pattern());
 
-    KLineEdit *lineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("replace"));
+    auto *lineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("replace"));
     Q_ASSERT(lineEdit);
     lineEdit->setText(mReplacementString);
 }
@@ -188,7 +170,7 @@ void FilterActionRewriteHeader::applyParamWidgetValue(QWidget *paramWidget)
 
     const KLineEdit *regExpLineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("search"));
     Q_ASSERT(regExpLineEdit);
-    mRegExp.setPattern(regExpLineEdit->text());
+    mRegex.setPattern(regExpLineEdit->text());
 
     const KLineEdit *lineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("replace"));
     Q_ASSERT(lineEdit);
@@ -201,11 +183,11 @@ void FilterActionRewriteHeader::clearParamWidget(QWidget *paramWidget) const
     Q_ASSERT(comboBox);
     comboBox->setCurrentIndex(0);
 
-    KLineEdit *regExpLineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("search"));
+    auto *regExpLineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("search"));
     Q_ASSERT(regExpLineEdit);
     regExpLineEdit->clear();
 
-    KLineEdit *lineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("replace"));
+    auto *lineEdit = paramWidget->findChild<KLineEdit *>(QStringLiteral("replace"));
     Q_ASSERT(lineEdit);
     lineEdit->clear();
 }
@@ -214,7 +196,7 @@ QString FilterActionRewriteHeader::argsAsString() const
 {
     QString result = mParameter;
     result += QLatin1Char('\t');
-    result += mRegExp.pattern();
+    result += mRegex.pattern();
     result += QLatin1Char('\t');
     result += mReplacementString;
 
@@ -234,9 +216,9 @@ void FilterActionRewriteHeader::argsFromString(const QString &argsStr)
     }
     QString result;
 
-    result = list[ 0 ];
-    mRegExp.setPattern(list[ 1 ]);
-    mReplacementString = list[ 2 ];
+    result = list[0];
+    mRegex.setPattern(list[1]);
+    mReplacementString = list[2];
 
     int index = mParameterList.indexOf(result);
     if (index < 0) {
