@@ -1,27 +1,15 @@
 /*
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
 #include "filteractionsetidentity.h"
 #include <MessageCore/StringUtil>
 
-#include "kernel/mailkernel.h"
 #include "filter/dialog/filteractionmissingidentitydialog.h"
+#include "kernel/mailkernel.h"
 
 #include <KIdentityManagement/Identity>
 #include <KIdentityManagement/IdentityCombo>
@@ -62,20 +50,19 @@ bool FilterActionSetIdentity::argsFromStringInteractive(const QString &argsStr,
 
 FilterAction::ReturnCode FilterActionSetIdentity::process(ItemContext &context, bool applyOnOutbound) const
 {
-    const KIdentityManagement::Identity &ident
-        = KernelIf->identityManager()->identityForUoid(mParameter);
+    const KIdentityManagement::Identity &ident = KernelIf->identityManager()->identityForUoid(mParameter);
 
     if (ident.isNull()) {
         return ErrorButGoOn;
     }
 
-    const KMime::Message::Ptr msg = context.item().payload<KMime::Message::Ptr>();
+    const auto msg = context.item().payload<KMime::Message::Ptr>();
     uint currentId = 0;
     if (auto hrd = msg->headerByType("X-KMail-Identity")) {
         currentId = hrd->asUnicodeString().trimmed().toUInt();
     }
     if (currentId != mParameter) {
-        KMime::Headers::Generic *header = new KMime::Headers::Generic("X-KMail-Identity");
+        auto header = new KMime::Headers::Generic("X-KMail-Identity");
         header->fromUnicodeString(QString::number(mParameter), "utf-8");
         if (applyOnOutbound) {
             msg->from()->fromUnicodeString(ident.fullEmailAddr(), "utf-8");
@@ -102,11 +89,11 @@ SearchRule::RequiredPart FilterActionSetIdentity::requiredPart() const
 
 QWidget *FilterActionSetIdentity::createParamWidget(QWidget *parent) const
 {
-    KIdentityManagement::IdentityCombo *comboBox = new KIdentityManagement::IdentityCombo(KernelIf->identityManager(), parent);
+    auto comboBox = new KIdentityManagement::IdentityCombo(KernelIf->identityManager(), parent);
     comboBox->setObjectName(QStringLiteral("identitycombobox"));
     comboBox->setCurrentIdentity(mParameter);
 
-    connect(comboBox, QOverload<int>::of(&KIdentityManagement::IdentityCombo::currentIndexChanged), this, &FilterActionSetIdentity::filterActionModified);
+    connect(comboBox, qOverload<int>(&KIdentityManagement::IdentityCombo::currentIndexChanged), this, &FilterActionSetIdentity::filterActionModified);
     return comboBox;
 }
 
@@ -120,7 +107,7 @@ void FilterActionSetIdentity::applyParamWidgetValue(QWidget *paramWidget)
 
 void FilterActionSetIdentity::clearParamWidget(QWidget *paramWidget) const
 {
-    KIdentityManagement::IdentityCombo *comboBox = qobject_cast<KIdentityManagement::IdentityCombo *>(paramWidget);
+    auto comboBox = qobject_cast<KIdentityManagement::IdentityCombo *>(paramWidget);
     Q_ASSERT(comboBox);
 
     comboBox->setCurrentIndex(0);
@@ -128,7 +115,7 @@ void FilterActionSetIdentity::clearParamWidget(QWidget *paramWidget) const
 
 void FilterActionSetIdentity::setParamWidgetValue(QWidget *paramWidget) const
 {
-    KIdentityManagement::IdentityCombo *comboBox = qobject_cast<KIdentityManagement::IdentityCombo *>(paramWidget);
+    auto comboBox = qobject_cast<KIdentityManagement::IdentityCombo *>(paramWidget);
     Q_ASSERT(comboBox);
 
     comboBox->setCurrentIdentity(mParameter);
