@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -30,9 +30,9 @@ public:
     Q_REQUIRED_RESULT MailFilter *parseLine(const QString &line);
 
 private:
-    Q_REQUIRED_RESULT QString extractString(const QString &tmp, int &pos);
-    Q_REQUIRED_RESULT QString extractConditions(const QString &line, MailFilter *filter);
-    Q_REQUIRED_RESULT QString extractActions(const QString &line, MailFilter *filter);
-    void readStream(QTextStream &stream);
+    Q_REQUIRED_RESULT MAILCOMMON_NO_EXPORT QString extractString(const QString &tmp, int &pos);
+    Q_REQUIRED_RESULT MAILCOMMON_NO_EXPORT QString extractConditions(const QString &line, MailFilter *filter);
+    Q_REQUIRED_RESULT MAILCOMMON_NO_EXPORT QString extractActions(const QString &line, MailFilter *filter);
+    MAILCOMMON_NO_EXPORT void readStream(QTextStream &stream);
 };
 }
