@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,9 +12,7 @@ FilterImporterPathCache::FilterImporterPathCache(QObject *parent)
 {
 }
 
-FilterImporterPathCache::~FilterImporterPathCache()
-{
-}
+FilterImporterPathCache::~FilterImporterPathCache() = default;
 
 FilterImporterPathCache *FilterImporterPathCache::self()
 {
