@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,9 +21,7 @@ InvalidFilterListView::InvalidFilterListView(QWidget *parent)
     setItemDelegate(invalidFilterDelegate);
 }
 
-InvalidFilterListView::~InvalidFilterListView()
-{
-}
+InvalidFilterListView::~InvalidFilterListView() = default;
 
 void InvalidFilterListView::setInvalidFilters(const QVector<MailCommon::InvalidFilterInfo> &lst)
 {
