@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -32,9 +32,7 @@ KMFilterAccountList::KMFilterAccountList(QWidget *parent)
     header()->setSectionsMovable(false);
 }
 
-KMFilterAccountList::~KMFilterAccountList()
-{
-}
+KMFilterAccountList::~KMFilterAccountList() = default;
 
 void KMFilterAccountList::updateAccountList(MailCommon::MailFilter *filter)
 {
