@@ -2,7 +2,7 @@
   Filter Dialog
 
   SPDX-FileCopyrightText: Marc Mutz <mutz@kde.org>
-  SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2011-2023 Laurent Montel <montel@kde.org>
 
   based upon work by Stefan Taferner <taferner@kde.org>
 
@@ -186,12 +186,10 @@ protected Q_SLOTS:
 
     void slotFolderChanged(const Akonadi::Collection &);
 
-private Q_SLOTS:
-    void slotExportAsSieveScript();
-    void slotHelp();
-
 private:
-    void importFilters(MailCommon::FilterImporterExporter::FilterType type);
+    MAILCOMMON_NO_EXPORT void slotExportAsSieveScript();
+    MAILCOMMON_NO_EXPORT void slotHelp();
+    MAILCOMMON_NO_EXPORT void importFilters(MailCommon::FilterImporterExporter::FilterType type);
 
 protected:
     bool event(QEvent *e) override;
@@ -239,4 +237,3 @@ protected:
     QWidget *mInMenuWidget = nullptr;
 };
 }
-
