@@ -1,6 +1,6 @@
 /*
 
-  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,7 +22,6 @@
 #include <QActionGroup>
 #include <QHeaderView>
 #include <QMouseEvent>
-#include <kwidgetsaddons_version.h>
 
 using namespace MailCommon;
 
@@ -470,11 +469,7 @@ bool FolderTreeView::allowedToEnterFolder(const Akonadi::Collection &collection,
     // warn user that going to next folder - but keep track of
     // whether he wishes to be notified again in "AskNextFolder"
     // parameter (kept in the config file for kmail)
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     const int result = KMessageBox::questionTwoActions(const_cast<FolderTreeView *>(this),
-#else
-    const int result = KMessageBox::questionYesNo(const_cast<FolderTreeView *>(this),
-#endif
                                                        i18n("<qt>Go to the next unread message in folder <b>%1</b>?</qt>", collection.name()),
                                                        i18n("Go to Next Unread Message"),
                                                        KGuiItem(i18n("Go To")),
@@ -482,11 +477,7 @@ bool FolderTreeView::allowedToEnterFolder(const Akonadi::Collection &collection,
                                                        QStringLiteral(":kmail_AskNextFolder"),
                                                        KMessageBox::Option());
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
     return result == KMessageBox::ButtonCode::PrimaryAction;
-#else
-    return result == KMessageBox::Yes;
-#endif
 }
 
 bool FolderTreeView::isUnreadFolder(const QModelIndex &current, QModelIndex &index, FolderTreeView::Move move, bool confirm)
@@ -520,23 +511,14 @@ bool FolderTreeView::isUnreadFolder(const QModelIndex &current, QModelIndex &ind
                         // warn user that going to next folder - but keep track of
                         // whether he wishes to be notified again in "AskNextFolder"
                         // parameter (kept in the config file for kmail)
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                         if (KMessageBox::questionTwoActions(this,
-#else
-                        if (KMessageBox::questionYesNo(this,
-
-#endif
                                                             i18n("<qt>Go to the next unread message in folder <b>%1</b>?</qt>", collection.name()),
                                                             i18n("Go to Next Unread Message"),
                                                             KGuiItem(i18n("Go To")),
                                                             KGuiItem(i18n("Do Not Go To")), // defaults
                                                             QStringLiteral(":kmail_AskNextFolder"),
                                                             KMessageBox::Option())
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                             == KMessageBox::ButtonCode::SecondaryAction) {
-#else
-                            == KMessageBox::No) {
-#endif
                             return true; // assume selected (do not continue looping)
                         }
 
