@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -190,7 +190,7 @@ bool FolderTreeWidgetProxyModel::filterAcceptsRow(int sourceRow, const QModelInd
 
     if (d->hideSpecificFolder) {
         const QSharedPointer<FolderSettings> col = FolderSettings::forCollection(collection, false);
-        if (col && col->hideInSelectionDialog()) {
+        if (!col.isNull() && col->hideInSelectionDialog()) {
             return false;
         }
     }
