@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,9 +18,7 @@ public:
     {
     }
 
-    ~DateRuleWidgetHandler() override
-    {
-    }
+    ~DateRuleWidgetHandler() override = default;
 
     QWidget *createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const override;
 
@@ -41,7 +39,7 @@ public:
     bool update(const QByteArray &field, QStackedWidget *functionStack, QStackedWidget *valueStack) const override;
 
 private:
-    SearchRule::Function currentFunction(const QStackedWidget *functionStack) const;
-    QString currentValue(const QStackedWidget *valueStack) const;
+    Q_REQUIRED_RESULT SearchRule::Function currentFunction(const QStackedWidget *functionStack) const;
+    Q_REQUIRED_RESULT QString currentValue(const QStackedWidget *valueStack) const;
 };
 }
