@@ -1,50 +1,32 @@
 /*
-  Copyright (c) 2017  Daniel Vrátil <dvratil@kde.org>
+  SPDX-FileCopyrightText: 2017 Daniel Vrátil <dvratil@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "encryptionwidgethandler.h"
+#include <KLazyLocalizedString>
 #include <QComboBox>
-#include <QStackedWidget>
 #include <QLabel>
-
+#include <QStackedWidget>
 using namespace MailCommon;
 
 static const struct {
     SearchRule::Function id;
-    const char *displayName;
-} EncryptionFunctions[] = {
-    { SearchRule::FuncEquals, I18N_NOOP("is")         },
-    { SearchRule::FuncNotEqual, I18N_NOOP("is not")      }
-};
-static const int EncryptionFunctionCount
-    = sizeof(EncryptionFunctions) / sizeof(*EncryptionFunctions);
+    const KLazyLocalizedString displayName;
+} EncryptionFunctions[] = {{SearchRule::FuncEquals, kli18n("is")}, {SearchRule::FuncNotEqual, kli18n("is not")}};
+static const int EncryptionFunctionCount = sizeof(EncryptionFunctions) / sizeof(*EncryptionFunctions);
 
 EncryptionWidgetHandler::EncryptionWidgetHandler()
     : RuleWidgetHandler()
 {
 }
 
-EncryptionWidgetHandler::~EncryptionWidgetHandler()
-{
-}
+EncryptionWidgetHandler::~EncryptionWidgetHandler() = default;
 
 QWidget *EncryptionWidgetHandler::createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const
 {
-    Q_UNUSED(isBalooSearch);
+    Q_UNUSED(isBalooSearch)
 
     if (number != 0) {
         return nullptr;
@@ -54,17 +36,16 @@ QWidget *EncryptionWidgetHandler::createFunctionWidget(int number, QStackedWidge
     combo->setMinimumWidth(50);
     combo->setObjectName(QStringLiteral("encryptionRuleFuncCombo"));
     for (int i = 0; i < EncryptionFunctionCount; ++i) {
-        combo->addItem(i18n(EncryptionFunctions[i].displayName));
+        combo->addItem(EncryptionFunctions[i].displayName.toString());
     }
     combo->adjustSize();
-    QObject::connect(combo, SIGNAL(activated(int)),
-                     receiver, SLOT(slotFunctionChanged()));
+    QObject::connect(combo, SIGNAL(activated(int)), receiver, SLOT(slotFunctionChanged()));
     return combo;
 }
 
 QWidget *EncryptionWidgetHandler::createValueWidget(int number, QStackedWidget *valueStack, const QObject *receiver) const
 {
-    Q_UNUSED(receiver);
+    Q_UNUSED(receiver)
 
     if (number != 0) {
         return nullptr;
@@ -91,20 +72,20 @@ SearchRule::Function EncryptionWidgetHandler::function(const QByteArray &field,
 
 QString EncryptionWidgetHandler::value(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const
 {
-    Q_UNUSED(functionStack);
-    Q_UNUSED(valueStack);
+    Q_UNUSED(functionStack)
+    Q_UNUSED(valueStack)
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
     return QStringLiteral("is encrypted"); // dummy value
 }
 
 QString EncryptionWidgetHandler::prettyValue(const QByteArray &field, const QStackedWidget *functionStack, const QStackedWidget *valueStack) const
 {
-    Q_UNUSED(functionStack);
-    Q_UNUSED(valueStack);
+    Q_UNUSED(functionStack)
+    Q_UNUSED(valueStack)
     if (!handlesField(field)) {
-        return QString();
+        return {};
     }
 
     return i18n("is encrypted");
@@ -124,12 +105,12 @@ void EncryptionWidgetHandler::reset(QStackedWidget *functionStack, QStackedWidge
         combo->blockSignals(blocked);
     }
 
-    Q_UNUSED(valueStack);
+    Q_UNUSED(valueStack)
 }
 
 bool EncryptionWidgetHandler::setRule(QStackedWidget *functionStack, QStackedWidget *valueStack, const SearchRule::Ptr rule, bool isBalooSearch) const
 {
-    Q_UNUSED(isBalooSearch);
+    Q_UNUSED(isBalooSearch)
     if (!rule || !handlesField(rule->field())) {
         reset(functionStack, valueStack);
         return false;
