@@ -1,37 +1,24 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef HEADERSRULERWIDGETHANDLER_H
-#define HEADERSRULERWIDGETHANDLER_H
+#pragma once
 
 #include "interfaces/rulewidgethandler.h"
 
-namespace MailCommon {
+namespace MailCommon
+{
 class HeadersRuleWidgetHandler : public MailCommon::RuleWidgetHandler
 {
 public:
-    HeadersRuleWidgetHandler() : MailCommon::RuleWidgetHandler()
+    HeadersRuleWidgetHandler()
+        : MailCommon::RuleWidgetHandler()
     {
     }
 
-    ~HeadersRuleWidgetHandler() override
-    {
-    }
+    ~HeadersRuleWidgetHandler() override = default;
 
     QWidget *createFunctionWidget(int number, QStackedWidget *functionStack, const QObject *receiver, bool isBalooSearch) const override;
 
@@ -56,4 +43,3 @@ private:
     QString currentValue(const QStackedWidget *valueStack, SearchRule::Function func) const;
 };
 }
-#endif // HEADERSRULERWIDGETHANDLER_H
