@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -28,8 +28,7 @@ public:
 
 private:
     void insertVariable(MessageComposer::ConvertSnippetVariablesUtil::VariableType variable);
-    QLineEdit *mLineEdit = nullptr;
+    QLineEdit *const mLineEdit;
     MessageComposer::ConvertSnippetVariableMenu *mConvertMenu = nullptr;
 };
 }
-
