@@ -2,7 +2,7 @@
   snippet feature from kdevelop/plugins/snippet/
 
   SPDX-FileCopyrightText: 2007 Robert Gruber <rgruber@users.sourceforge.net>
-  SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -59,17 +59,16 @@ public:
 
     void setAttachment(const QString &keyword);
     Q_REQUIRED_RESULT QString attachment() const;
-private Q_SLOTS:
-    void slotTextChanged();
-    void slotGroupChanged();
 
 private:
+    void slotTextChanged();
+    void slotGroupChanged();
     bool snippetIsValid() const;
     void writeConfig();
     void readConfig();
 
     KActionCollection *mActionCollection = nullptr;
-    SnippetWidget *mSnippetWidget = nullptr;
+    SnippetWidget *const mSnippetWidget;
     QPushButton *mOkButton = nullptr;
     bool mInGroupMode = false;
 };
