@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
@@ -37,7 +37,6 @@ public:
     Q_REQUIRED_RESULT QStringList attachments() const;
 
 private:
-    SnippetSelectorWidget *mEditor = nullptr;
+    SnippetSelectorWidget *const mEditor;
 };
 }
-
