@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,9 +21,7 @@ using namespace MailCommon;
 class MailCommon::AddTagDialogPrivate
 {
 public:
-    AddTagDialogPrivate()
-    {
-    }
+    AddTagDialogPrivate() = default;
 
     QString mLabel;
     QString mGid;
@@ -48,7 +46,7 @@ AddTagDialog::AddTagDialog(const QList<KActionCollection *> &actions, QWidget *p
 
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     d->mOkButton = buttonBox->button(QDialogButtonBox::Ok);
-    d->mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    d->mOkButton->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_Return));
     connect(buttonBox, &QDialogButtonBox::accepted, this, &AddTagDialog::slotSave);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &AddTagDialog::reject);
     d->mOkButton->setDefault(true);
