@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -13,9 +13,7 @@ using namespace MailCommon;
 class MailCommon::ResourceReadConfigFilePrivate
 {
 public:
-    ResourceReadConfigFilePrivate()
-    {
-    }
+    ResourceReadConfigFilePrivate() = default;
 
     ~ResourceReadConfigFilePrivate()
     {
@@ -38,5 +36,5 @@ KConfigGroup ResourceReadConfigFile::group(const QString &name) const
     if (d->mConfig) {
         return d->mConfig->group(name);
     }
-    return KConfigGroup();
+    return {};
 }
